##  Overview
Simple Mail Transfer Protocol (SMTP) is an internet standard for email transmission across IP networks. You can set up a custom SMTP server to deliver SAP LeanIX notifications instead of using the default SAP LeanIX email service. This approach gives you greater control and enhances security standards for the delivery process.
Our implementation of SMTP supports the STARTTLS extension and is compatible with the TLS protocol up to version 1.2.
**Note**
If you set up a custom SMTP server for email delivery, this configuration applies at the account level across all of your organization’s workspaces.
